==> qmmp-0.12.4.tar.bz2: qmmp-0.12.4/src/qmmp/fileinputsource_p.h <==
/***************************************************************************
 *   Copyright (C) 2009 by Ilya Kotov                                      *
 *   forkotov02@ya.ru                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#ifndef FILEINPUTSOURCE_P_H
#define FILEINPUTSOURCE_P_H

#include "inputsource.h"

class QFile;

/** @internal
    @author Ilya Kotov <forkotov02@ya.ru>
*/
class FileInputSource : public InputSource
{
Q_OBJECT
public:
    FileInputSource(const QString &path, QObject *parent = 0);

    QIODevice *ioDevice();
    bool initialize();
    bool isReady();

private:
    QFile *m_file;
};

#endif // FILEINPUTSOURCE_P_H

==> qmmp_1.0.5.orig.tar.bz2: qmmp-1.0.5/src/qmmp/fileinputsource_p.h <==
/***************************************************************************
 *   Copyright (C) 2009 by Ilya Kotov                                      *
 *   forkotov02@hotmail.ru                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#ifndef FILEINPUTSOURCE_P_H
#define FILEINPUTSOURCE_P_H

#include "inputsource.h"

class QFile;

/** @internal
    @author Ilya Kotov <forkotov02@hotmail.ru>
*/
class FileInputSource : public InputSource
{
Q_OBJECT
public:
    FileInputSource(const QString &url, QObject *parent = 0);

    QIODevice *ioDevice();
    bool initialize();
    bool isReady();

private:
    QFile *m_file;
};

#endif // FILEINPUTSOURCE_P_H
